@@ -1,5 +1,9 @@
 """
-Nextstrain command-line tool
+Nextstrain command-line interface (CLI)
+
+The `nextstrain` program and its subcommands aim to provide a consistent way to
+run and visualize pathogen builds and access Nextstrain components like Augur
+and Auspice across computing environments such as Docker, Conda, and AWS Batch.
 """
 
 
@@ -24,6 +28,18 @@ def run(args):
     Command-line entrypoint to the nextstrain-cli package, called by the
     `nextstrain` program.
     """
+    parser = make_parser()
+    opts = parser.parse_args(args)
+
+    try:
+        return opts.__command__.run(opts)
+
+    except NextstrainCliError as error:
+        warn(error)
+        return 1
+
+
+def make_parser():
     parser = ArgumentParser(
         prog            = "nextstrain",
         description     = __doc__,
@@ -50,14 +66,7 @@ def run(args):
     register_commands(parser, commands)
     register_version_alias(parser)
 
-    opts = parser.parse_args(args)
-
-    try:
-        return opts.__command__.run(opts)
-
-    except NextstrainCliError as error:
-        warn(error)
-        return 1
+    return parser
 
 
 def register_version_alias(parser):
